Crate jid_gst_meet

Crate jid_gst_meet 

Provides a type for Jabber IDs.

For usage, check the documentation on the Jid struct.

Structs

BareJid
A struct representing a bare Jabber ID.
FullJid
A struct representing a full Jabber ID.

Enums

Jid
An enum representing a Jabber ID. It can be either a FullJid or a BareJid.
JidParseError
An error that signifies that a Jid cannot be parsed from a string.